version

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 24, 2024 License: BSD-3-Clause Imports: 1 Imported by: 0

Documentation

Overview

Package version provides the application version.

Index

Constants

const (
	Major    int = 0 // The major version number
	Minor    int = 4 // The minor version number
	Revision int = 0 // The revision number
)

Variables

var (
	Build string = "" // The build number
)

Functions

func Long

func Long() string

Long returns the version number in the format Major.Minor.Revision (build Build).

func Short

func Short() string

Short returns the version number in the format Major.Minor.Revision.

func Version

func Version() string

Version returns the version number in the format Major.Minor.Revision.Build.

Types

This section is empty.

Jump to